# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_medmesh')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_medmesh')
    _medmesh = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_medmesh', [dirname(__file__)])
        except ImportError:
            import _medmesh
            return _medmesh
        try:
            _mod = imp.load_module('_medmesh', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _medmesh = swig_import_helper()
    del swig_import_helper
else:
    import _medmesh
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

class SwigPyIterator_medmesh_module(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, SwigPyIterator_medmesh_module, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, SwigPyIterator_medmesh_module, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medmesh.delete_SwigPyIterator_medmesh_module
    __del__ = lambda self: None

    def value(self) -> "PyObject *":
        return _medmesh.SwigPyIterator_medmesh_module_value(self)

    def incr(self, n: 'size_t'=1) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.SwigPyIterator_medmesh_module_incr(self, n)

    def decr(self, n: 'size_t'=1) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.SwigPyIterator_medmesh_module_decr(self, n)

    def distance(self, x: 'SwigPyIterator_medmesh_module') -> "ptrdiff_t":
        return _medmesh.SwigPyIterator_medmesh_module_distance(self, x)

    def equal(self, x: 'SwigPyIterator_medmesh_module') -> "bool":
        return _medmesh.SwigPyIterator_medmesh_module_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.SwigPyIterator_medmesh_module_copy(self)

    def next(self) -> "PyObject *":
        return _medmesh.SwigPyIterator_medmesh_module_next(self)

    def __next__(self) -> "PyObject *":
        return _medmesh.SwigPyIterator_medmesh_module___next__(self)

    def previous(self) -> "PyObject *":
        return _medmesh.SwigPyIterator_medmesh_module_previous(self)

    def advance(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.SwigPyIterator_medmesh_module_advance(self, n)

    def __eq__(self, x: 'SwigPyIterator_medmesh_module') -> "bool":
        return _medmesh.SwigPyIterator_medmesh_module___eq__(self, x)

    def __ne__(self, x: 'SwigPyIterator_medmesh_module') -> "bool":
        return _medmesh.SwigPyIterator_medmesh_module___ne__(self, x)

    def __iadd__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medmesh_module &":
        return _medmesh.SwigPyIterator_medmesh_module___iadd__(self, n)

    def __isub__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medmesh_module &":
        return _medmesh.SwigPyIterator_medmesh_module___isub__(self, n)

    def __add__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.SwigPyIterator_medmesh_module___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _medmesh.SwigPyIterator_medmesh_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self
SwigPyIterator_medmesh_module_swigregister = _medmesh.SwigPyIterator_medmesh_module_swigregister
SwigPyIterator_medmesh_module_swigregister(SwigPyIterator_medmesh_module)

HAVE_CC_C99 = _medmesh.HAVE_CC_C99
HAVE_FTIME = _medmesh.HAVE_FTIME
HAVE_H5PUBLIC_H = _medmesh.HAVE_H5PUBLIC_H
HAVE_INT64 = _medmesh.HAVE_INT64
HAVE_INTTYPES_H = _medmesh.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medmesh.HAVE_MALLOC_H
HAVE_MEMORY_H = _medmesh.HAVE_MEMORY_H
HAVE_STDBOOL_H = _medmesh.HAVE_STDBOOL_H
HAVE_STDINT_H = _medmesh.HAVE_STDINT_H
HAVE_STDLIB_H = _medmesh.HAVE_STDLIB_H
HAVE_STRING_H = _medmesh.HAVE_STRING_H
HAVE_SYS_STAT_H = _medmesh.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medmesh.HAVE_SYS_TIMEB_H
HAVE_SYS_TYPES_H = _medmesh.HAVE_SYS_TYPES_H
HAVE__BOOL = _medmesh.HAVE__BOOL
MED_CHECK_23FORMAT = _medmesh.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medmesh.MED_HAVE_FORTRAN
MESGERR = _medmesh.MESGERR
PACKAGE = _medmesh.PACKAGE
PACKAGE_BUGREPORT = _medmesh.PACKAGE_BUGREPORT
PACKAGE_NAME = _medmesh.PACKAGE_NAME
PACKAGE_STRING = _medmesh.PACKAGE_STRING
PACKAGE_URL = _medmesh.PACKAGE_URL
PACKAGE_VERSION = _medmesh.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medmesh.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medmesh.SIZEOF_INT
SIZEOF_LONG = _medmesh.SIZEOF_LONG
STDC_HEADERS = _medmesh.STDC_HEADERS
VERSION = _medmesh.VERSION
HDF_VERSION_MAJOR_REF = _medmesh.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medmesh.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medmesh.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medmesh.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medmesh.H5F_LIBVER_18
MED_MAJOR_NUM = _medmesh.MED_MAJOR_NUM
MED_MINOR_NUM = _medmesh.MED_MINOR_NUM
MED_RELEASE_NUM = _medmesh.MED_RELEASE_NUM
MED_NUM_MAJEUR = _medmesh.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medmesh.MED_NUM_MINEUR
MED_NUM_RELEASE = _medmesh.MED_NUM_RELEASE
MED_VERSION_STR = _medmesh.MED_VERSION_STR
MED_MAX_PARA = _medmesh.MED_MAX_PARA
MED_COMMENT_SIZE = _medmesh.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medmesh.MED_IDENT_SIZE
MED_NAME_SIZE = _medmesh.MED_NAME_SIZE
MED_SNAME_SIZE = _medmesh.MED_SNAME_SIZE
MED_LNAME_SIZE = _medmesh.MED_LNAME_SIZE
MED_SNAME_BLANK = _medmesh.MED_SNAME_BLANK
MED_NAME_BLANK = _medmesh.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medmesh.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medmesh.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medmesh.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medmesh.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medmesh.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medmesh.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medmesh.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medmesh.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medmesh.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medmesh.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medmesh.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medmesh.MED_ACC_RDONLY
MED_ACC_RDWR = _medmesh.MED_ACC_RDWR
MED_ACC_RDEXT = _medmesh.MED_ACC_RDEXT
MED_ACC_CREAT = _medmesh.MED_ACC_CREAT
MED_ACC_UNDEF = _medmesh.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medmesh.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medmesh.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medmesh.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medmesh.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medmesh.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medmesh.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medmesh.MED_UNDEF_GRID_TYPE
MED_CELL = _medmesh.MED_CELL
MED_DESCENDING_FACE = _medmesh.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medmesh.MED_DESCENDING_EDGE
MED_NODE = _medmesh.MED_NODE
MED_NODE_ELEMENT = _medmesh.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medmesh.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medmesh.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medmesh.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medmesh.MED_N_ENTITY_TYPES
MED_COORDINATE = _medmesh.MED_COORDINATE
MED_CONNECTIVITY = _medmesh.MED_CONNECTIVITY
MED_NAME = _medmesh.MED_NAME
MED_NUMBER = _medmesh.MED_NUMBER
MED_FAMILY_NUMBER = _medmesh.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medmesh.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medmesh.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medmesh.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medmesh.MED_INDEX_FACE
MED_INDEX_NODE = _medmesh.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medmesh.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medmesh.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medmesh.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medmesh.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medmesh.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medmesh.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT32 = _medmesh.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medmesh.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medmesh.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medmesh.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medmesh.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medmesh.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medmesh.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medmesh.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medmesh.MED_INTERNAL_UNDEF
MED_DOUBLE = _medmesh.MED_DOUBLE
MED_FLOAT64 = _medmesh.MED_FLOAT64
MED_FLOAT32 = _medmesh.MED_FLOAT32
MED_INT32 = _medmesh.MED_INT32
MED_INT64 = _medmesh.MED_INT64
MED_INT = _medmesh.MED_INT
MED_ATT_FLOAT64 = _medmesh.MED_ATT_FLOAT64
MED_ATT_INT = _medmesh.MED_ATT_INT
MED_ATT_NAME = _medmesh.MED_ATT_NAME
MED_ATT_UNDEF = _medmesh.MED_ATT_UNDEF
MED_MESH = _medmesh.MED_MESH
MED_FIELD = _medmesh.MED_FIELD
MED_LIBRARY = _medmesh.MED_LIBRARY
MED_FILE = _medmesh.MED_FILE
MED_MESH_SUPPORT = _medmesh.MED_MESH_SUPPORT
MED_ELSTRUCT = _medmesh.MED_ELSTRUCT
MED_FAMILY = _medmesh.MED_FAMILY
MED_EQUIVALENCE = _medmesh.MED_EQUIVALENCE
MED_GROUP = _medmesh.MED_GROUP
MED_JOINT = _medmesh.MED_JOINT
MED_LOCALIZATION = _medmesh.MED_LOCALIZATION
MED_PROFILE = _medmesh.MED_PROFILE
MED_FILTER = _medmesh.MED_FILTER
MED_INTERPOLATION = _medmesh.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medmesh.MED_NUMERICAL_DATA
MED_LINK = _medmesh.MED_LINK
MED_CLASS_UNDEF = _medmesh.MED_CLASS_UNDEF
MED_CLASS_ALL = _medmesh.MED_CLASS_ALL
MED_POINT1 = _medmesh.MED_POINT1
MED_SEG2 = _medmesh.MED_SEG2
MED_SEG3 = _medmesh.MED_SEG3
MED_SEG4 = _medmesh.MED_SEG4
MED_TRIA3 = _medmesh.MED_TRIA3
MED_QUAD4 = _medmesh.MED_QUAD4
MED_TRIA6 = _medmesh.MED_TRIA6
MED_TRIA7 = _medmesh.MED_TRIA7
MED_QUAD8 = _medmesh.MED_QUAD8
MED_QUAD9 = _medmesh.MED_QUAD9
MED_TETRA4 = _medmesh.MED_TETRA4
MED_PYRA5 = _medmesh.MED_PYRA5
MED_PENTA6 = _medmesh.MED_PENTA6
MED_HEXA8 = _medmesh.MED_HEXA8
MED_TETRA10 = _medmesh.MED_TETRA10
MED_OCTA12 = _medmesh.MED_OCTA12
MED_PYRA13 = _medmesh.MED_PYRA13
MED_PENTA15 = _medmesh.MED_PENTA15
MED_PENTA18 = _medmesh.MED_PENTA18
MED_HEXA20 = _medmesh.MED_HEXA20
MED_HEXA27 = _medmesh.MED_HEXA27
MED_POLYGON = _medmesh.MED_POLYGON
MED_POLYGON2 = _medmesh.MED_POLYGON2
MED_POLYHEDRON = _medmesh.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medmesh.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medmesh.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medmesh.MED_NONE
MED_NO_GEOTYPE = _medmesh.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medmesh.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medmesh.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medmesh.MED_ALL_GEOTYPE
MED_GEO_ALL = _medmesh.MED_GEO_ALL
MED_N_CELL_GEO = _medmesh.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medmesh.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medmesh.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medmesh.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medmesh.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medmesh.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medmesh.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medmesh.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medmesh.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medmesh.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medmesh.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medmesh.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medmesh.MED_NODAL
MED_DESCENDING = _medmesh.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medmesh.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medmesh.MED_NO_CMODE
MED_CARTESIAN = _medmesh.MED_CARTESIAN
MED_CYLINDRICAL = _medmesh.MED_CYLINDRICAL
MED_SPHERICAL = _medmesh.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medmesh.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medmesh.MED_FALSE
MED_TRUE = _medmesh.MED_TRUE
MED_GAUSS_ELNO = _medmesh.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medmesh.MED_IPOINT_ELNO
MED_NO_NAME = _medmesh.MED_NO_NAME
MED_NO_MESHNAME = _medmesh.MED_NO_MESHNAME
MED_NO_MESH = _medmesh.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medmesh.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medmesh.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medmesh.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medmesh.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medmesh.MED_NO_PROFILE
MED_NO_GROUP = _medmesh.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medmesh.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medmesh.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medmesh.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medmesh.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medmesh.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medmesh.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medmesh.MED_SORT_DTIT
MED_SORT_ITDT = _medmesh.MED_SORT_ITDT
MED_SORT_UNDEF = _medmesh.MED_SORT_UNDEF
MED_NO_DT = _medmesh.MED_NO_DT
MED_NO_IT = _medmesh.MED_NO_IT
MED_UNDEF_DT = _medmesh.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medmesh.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medmesh.MED_MAX_FILTER_SPACES
class med_filter(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_filter, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_filter, name)
    __repr__ = _swig_repr
    __swig_setmethods__["nspaces"] = _medmesh.med_filter_nspaces_set
    __swig_getmethods__["nspaces"] = _medmesh.med_filter_nspaces_get
    if _newclass:
        nspaces = _swig_property(_medmesh.med_filter_nspaces_get, _medmesh.med_filter_nspaces_set)
    __swig_setmethods__["memspace"] = _medmesh.med_filter_memspace_set
    __swig_getmethods__["memspace"] = _medmesh.med_filter_memspace_get
    if _newclass:
        memspace = _swig_property(_medmesh.med_filter_memspace_get, _medmesh.med_filter_memspace_set)
    __swig_setmethods__["diskspace"] = _medmesh.med_filter_diskspace_set
    __swig_getmethods__["diskspace"] = _medmesh.med_filter_diskspace_get
    if _newclass:
        diskspace = _swig_property(_medmesh.med_filter_diskspace_get, _medmesh.med_filter_diskspace_set)
    __swig_setmethods__["nentity"] = _medmesh.med_filter_nentity_set
    __swig_getmethods__["nentity"] = _medmesh.med_filter_nentity_get
    if _newclass:
        nentity = _swig_property(_medmesh.med_filter_nentity_get, _medmesh.med_filter_nentity_set)
    __swig_setmethods__["nvaluesperentity"] = _medmesh.med_filter_nvaluesperentity_set
    __swig_getmethods__["nvaluesperentity"] = _medmesh.med_filter_nvaluesperentity_get
    if _newclass:
        nvaluesperentity = _swig_property(_medmesh.med_filter_nvaluesperentity_get, _medmesh.med_filter_nvaluesperentity_set)
    __swig_setmethods__["nconstituentpervalue"] = _medmesh.med_filter_nconstituentpervalue_set
    __swig_getmethods__["nconstituentpervalue"] = _medmesh.med_filter_nconstituentpervalue_get
    if _newclass:
        nconstituentpervalue = _swig_property(_medmesh.med_filter_nconstituentpervalue_get, _medmesh.med_filter_nconstituentpervalue_set)
    __swig_setmethods__["constituentselect"] = _medmesh.med_filter_constituentselect_set
    __swig_getmethods__["constituentselect"] = _medmesh.med_filter_constituentselect_get
    if _newclass:
        constituentselect = _swig_property(_medmesh.med_filter_constituentselect_get, _medmesh.med_filter_constituentselect_set)
    __swig_setmethods__["switchmode"] = _medmesh.med_filter_switchmode_set
    __swig_getmethods__["switchmode"] = _medmesh.med_filter_switchmode_get
    if _newclass:
        switchmode = _swig_property(_medmesh.med_filter_switchmode_get, _medmesh.med_filter_switchmode_set)
    __swig_setmethods__["filterarraysize"] = _medmesh.med_filter_filterarraysize_set
    __swig_getmethods__["filterarraysize"] = _medmesh.med_filter_filterarraysize_get
    if _newclass:
        filterarraysize = _swig_property(_medmesh.med_filter_filterarraysize_get, _medmesh.med_filter_filterarraysize_set)
    __swig_setmethods__["filterarray23v30"] = _medmesh.med_filter_filterarray23v30_set
    __swig_getmethods__["filterarray23v30"] = _medmesh.med_filter_filterarray23v30_get
    if _newclass:
        filterarray23v30 = _swig_property(_medmesh.med_filter_filterarray23v30_get, _medmesh.med_filter_filterarray23v30_set)
    __swig_setmethods__["profilearraysize"] = _medmesh.med_filter_profilearraysize_set
    __swig_getmethods__["profilearraysize"] = _medmesh.med_filter_profilearraysize_get
    if _newclass:
        profilearraysize = _swig_property(_medmesh.med_filter_profilearraysize_get, _medmesh.med_filter_profilearraysize_set)
    __swig_setmethods__["storagemode"] = _medmesh.med_filter_storagemode_set
    __swig_getmethods__["storagemode"] = _medmesh.med_filter_storagemode_get
    if _newclass:
        storagemode = _swig_property(_medmesh.med_filter_storagemode_get, _medmesh.med_filter_storagemode_set)
    __swig_setmethods__["profilename"] = _medmesh.med_filter_profilename_set
    __swig_getmethods__["profilename"] = _medmesh.med_filter_profilename_get
    if _newclass:
        profilename = _swig_property(_medmesh.med_filter_profilename_get, _medmesh.med_filter_profilename_set)

    def __init__(self):
        """__init__(self) -> med_filter"""
        this = _medmesh.new_med_filter()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medmesh.delete_med_filter
    __del__ = lambda self: None
med_filter_swigregister = _medmesh.med_filter_swigregister
med_filter_swigregister(med_filter)

MED_NO_FILTER_SIZE = _medmesh.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medmesh.MED_NO_PROFILE_F
class med_file_version(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_file_version, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_file_version, name)
    __repr__ = _swig_repr
    __swig_setmethods__["majeur"] = _medmesh.med_file_version_majeur_set
    __swig_getmethods__["majeur"] = _medmesh.med_file_version_majeur_get
    if _newclass:
        majeur = _swig_property(_medmesh.med_file_version_majeur_get, _medmesh.med_file_version_majeur_set)
    __swig_setmethods__["mineur"] = _medmesh.med_file_version_mineur_set
    __swig_getmethods__["mineur"] = _medmesh.med_file_version_mineur_get
    if _newclass:
        mineur = _swig_property(_medmesh.med_file_version_mineur_get, _medmesh.med_file_version_mineur_set)
    __swig_setmethods__["release"] = _medmesh.med_file_version_release_set
    __swig_getmethods__["release"] = _medmesh.med_file_version_release_get
    if _newclass:
        release = _swig_property(_medmesh.med_file_version_release_get, _medmesh.med_file_version_release_set)

    def __init__(self):
        """__init__(self) -> med_file_version"""
        this = _medmesh.new_med_file_version()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medmesh.delete_med_file_version
    __del__ = lambda self: None
med_file_version_swigregister = _medmesh.med_file_version_swigregister
med_file_version_swigregister(med_file_version)

class med_memfile(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_memfile, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_memfile, name)
    __repr__ = _swig_repr
    __swig_setmethods__["app_image_ptr"] = _medmesh.med_memfile_app_image_ptr_set
    __swig_getmethods__["app_image_ptr"] = _medmesh.med_memfile_app_image_ptr_get
    if _newclass:
        app_image_ptr = _swig_property(_medmesh.med_memfile_app_image_ptr_get, _medmesh.med_memfile_app_image_ptr_set)
    __swig_setmethods__["app_image_size"] = _medmesh.med_memfile_app_image_size_set
    __swig_getmethods__["app_image_size"] = _medmesh.med_memfile_app_image_size_get
    if _newclass:
        app_image_size = _swig_property(_medmesh.med_memfile_app_image_size_get, _medmesh.med_memfile_app_image_size_set)
    __swig_setmethods__["ref_count"] = _medmesh.med_memfile_ref_count_set
    __swig_getmethods__["ref_count"] = _medmesh.med_memfile_ref_count_get
    if _newclass:
        ref_count = _swig_property(_medmesh.med_memfile_ref_count_get, _medmesh.med_memfile_ref_count_set)
    __swig_setmethods__["fapl_image_ptr"] = _medmesh.med_memfile_fapl_image_ptr_set
    __swig_getmethods__["fapl_image_ptr"] = _medmesh.med_memfile_fapl_image_ptr_get
    if _newclass:
        fapl_image_ptr = _swig_property(_medmesh.med_memfile_fapl_image_ptr_get, _medmesh.med_memfile_fapl_image_ptr_set)
    __swig_setmethods__["fapl_image_size"] = _medmesh.med_memfile_fapl_image_size_set
    __swig_getmethods__["fapl_image_size"] = _medmesh.med_memfile_fapl_image_size_get
    if _newclass:
        fapl_image_size = _swig_property(_medmesh.med_memfile_fapl_image_size_get, _medmesh.med_memfile_fapl_image_size_set)
    __swig_setmethods__["fapl_ref_count"] = _medmesh.med_memfile_fapl_ref_count_set
    __swig_getmethods__["fapl_ref_count"] = _medmesh.med_memfile_fapl_ref_count_get
    if _newclass:
        fapl_ref_count = _swig_property(_medmesh.med_memfile_fapl_ref_count_get, _medmesh.med_memfile_fapl_ref_count_set)
    __swig_setmethods__["vfd_image_ptr"] = _medmesh.med_memfile_vfd_image_ptr_set
    __swig_getmethods__["vfd_image_ptr"] = _medmesh.med_memfile_vfd_image_ptr_get
    if _newclass:
        vfd_image_ptr = _swig_property(_medmesh.med_memfile_vfd_image_ptr_get, _medmesh.med_memfile_vfd_image_ptr_set)
    __swig_setmethods__["vfd_image_size"] = _medmesh.med_memfile_vfd_image_size_set
    __swig_getmethods__["vfd_image_size"] = _medmesh.med_memfile_vfd_image_size_get
    if _newclass:
        vfd_image_size = _swig_property(_medmesh.med_memfile_vfd_image_size_get, _medmesh.med_memfile_vfd_image_size_set)
    __swig_setmethods__["vfd_ref_count"] = _medmesh.med_memfile_vfd_ref_count_set
    __swig_getmethods__["vfd_ref_count"] = _medmesh.med_memfile_vfd_ref_count_get
    if _newclass:
        vfd_ref_count = _swig_property(_medmesh.med_memfile_vfd_ref_count_get, _medmesh.med_memfile_vfd_ref_count_set)
    __swig_setmethods__["flags"] = _medmesh.med_memfile_flags_set
    __swig_getmethods__["flags"] = _medmesh.med_memfile_flags_get
    if _newclass:
        flags = _swig_property(_medmesh.med_memfile_flags_get, _medmesh.med_memfile_flags_set)

    def __init__(self):
        """__init__(self) -> med_memfile"""
        this = _medmesh.new_med_memfile()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medmesh.delete_med_memfile
    __del__ = lambda self: None
med_memfile_swigregister = _medmesh.med_memfile_swigregister
med_memfile_swigregister(med_memfile)

MED_PARTICLE_NAME = _medmesh.MED_PARTICLE_NAME
MED_BALL_NAME = _medmesh.MED_BALL_NAME
MED_BEAM_NAME = _medmesh.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medmesh.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medmesh.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medmesh.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDBOOL, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDBOOL, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medmesh.MEDBOOL___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medmesh.MEDBOOL___bool__(self)

    def __len__(self) -> "std::vector< bool >::size_type":
        return _medmesh.MEDBOOL___len__(self)

    def __getslice__(self, i: 'std::vector< bool >::difference_type', j: 'std::vector< bool >::difference_type') -> "std::vector< bool,std::allocator< bool > > *":
        return _medmesh.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medmesh.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< bool >::difference_type', j: 'std::vector< bool >::difference_type') -> "void":
        return _medmesh.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medmesh.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< bool >::value_type":
        return _medmesh.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medmesh.MEDBOOL___setitem__(self, *args)

    def pop(self) -> "std::vector< bool >::value_type":
        return _medmesh.MEDBOOL_pop(self)

    def append(self, x: 'std::vector< bool >::value_type') -> "void":
        return _medmesh.MEDBOOL_append(self, x)

    def empty(self) -> "bool":
        return _medmesh.MEDBOOL_empty(self)

    def size(self) -> "std::vector< bool >::size_type":
        return _medmesh.MEDBOOL_size(self)

    def swap(self, v: 'MEDBOOL') -> "void":
        return _medmesh.MEDBOOL_swap(self, v)

    def begin(self) -> "std::vector< bool >::iterator":
        return _medmesh.MEDBOOL_begin(self)

    def end(self) -> "std::vector< bool >::iterator":
        return _medmesh.MEDBOOL_end(self)

    def rbegin(self) -> "std::vector< bool >::reverse_iterator":
        return _medmesh.MEDBOOL_rbegin(self)

    def rend(self) -> "std::vector< bool >::reverse_iterator":
        return _medmesh.MEDBOOL_rend(self)

    def clear(self) -> "void":
        return _medmesh.MEDBOOL_clear(self)

    def get_allocator(self) -> "std::vector< bool >::allocator_type":
        return _medmesh.MEDBOOL_get_allocator(self)

    def pop_back(self) -> "void":
        return _medmesh.MEDBOOL_pop_back(self)

    def erase(self, *args) -> "std::vector< bool >::iterator":
        return _medmesh.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        this = _medmesh.new_MEDBOOL(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< bool >::value_type') -> "void":
        return _medmesh.MEDBOOL_push_back(self, x)

    def front(self) -> "std::vector< bool >::value_type":
        return _medmesh.MEDBOOL_front(self)

    def back(self) -> "std::vector< bool >::value_type":
        return _medmesh.MEDBOOL_back(self)

    def assign(self, n: 'std::vector< bool >::size_type', x: 'std::vector< bool >::value_type') -> "void":
        return _medmesh.MEDBOOL_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medmesh.MEDBOOL_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medmesh.MEDBOOL_insert(self, *args)

    def reserve(self, n: 'std::vector< bool >::size_type') -> "void":
        return _medmesh.MEDBOOL_reserve(self, n)

    def capacity(self) -> "std::vector< bool >::size_type":
        return _medmesh.MEDBOOL_capacity(self)
    __swig_destroy__ = _medmesh.delete_MEDBOOL
    __del__ = lambda self: None
MEDBOOL_swigregister = _medmesh.MEDBOOL_swigregister
MEDBOOL_swigregister(MEDBOOL)
cvar = _medmesh.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medmesh.MEDFLOAT___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medmesh.MEDFLOAT___bool__(self)

    def __len__(self) -> "std::vector< double >::size_type":
        return _medmesh.MEDFLOAT___len__(self)

    def __getslice__(self, i: 'std::vector< double >::difference_type', j: 'std::vector< double >::difference_type') -> "std::vector< double,std::allocator< double > > *":
        return _medmesh.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medmesh.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< double >::difference_type', j: 'std::vector< double >::difference_type') -> "void":
        return _medmesh.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medmesh.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< double >::value_type const &":
        return _medmesh.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medmesh.MEDFLOAT___setitem__(self, *args)

    def pop(self) -> "std::vector< double >::value_type":
        return _medmesh.MEDFLOAT_pop(self)

    def append(self, x: 'std::vector< double >::value_type const &') -> "void":
        return _medmesh.MEDFLOAT_append(self, x)

    def empty(self) -> "bool":
        return _medmesh.MEDFLOAT_empty(self)

    def size(self) -> "std::vector< double >::size_type":
        return _medmesh.MEDFLOAT_size(self)

    def swap(self, v: 'MEDFLOAT') -> "void":
        return _medmesh.MEDFLOAT_swap(self, v)

    def begin(self) -> "std::vector< double >::iterator":
        return _medmesh.MEDFLOAT_begin(self)

    def end(self) -> "std::vector< double >::iterator":
        return _medmesh.MEDFLOAT_end(self)

    def rbegin(self) -> "std::vector< double >::reverse_iterator":
        return _medmesh.MEDFLOAT_rbegin(self)

    def rend(self) -> "std::vector< double >::reverse_iterator":
        return _medmesh.MEDFLOAT_rend(self)

    def clear(self) -> "void":
        return _medmesh.MEDFLOAT_clear(self)

    def get_allocator(self) -> "std::vector< double >::allocator_type":
        return _medmesh.MEDFLOAT_get_allocator(self)

    def pop_back(self) -> "void":
        return _medmesh.MEDFLOAT_pop_back(self)

    def erase(self, *args) -> "std::vector< double >::iterator":
        return _medmesh.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        this = _medmesh.new_MEDFLOAT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< double >::value_type const &') -> "void":
        return _medmesh.MEDFLOAT_push_back(self, x)

    def front(self) -> "std::vector< double >::value_type const &":
        return _medmesh.MEDFLOAT_front(self)

    def back(self) -> "std::vector< double >::value_type const &":
        return _medmesh.MEDFLOAT_back(self)

    def assign(self, n: 'std::vector< double >::size_type', x: 'std::vector< double >::value_type const &') -> "void":
        return _medmesh.MEDFLOAT_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medmesh.MEDFLOAT_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medmesh.MEDFLOAT_insert(self, *args)

    def reserve(self, n: 'std::vector< double >::size_type') -> "void":
        return _medmesh.MEDFLOAT_reserve(self, n)

    def capacity(self) -> "std::vector< double >::size_type":
        return _medmesh.MEDFLOAT_capacity(self)

    def __iadd__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medmesh.MEDFLOAT___iadd__(self, value)

    def __add__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medmesh.MEDFLOAT___add__(self, value)

    def __isub__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medmesh.MEDFLOAT___isub__(self, value)

    def __sub__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medmesh.MEDFLOAT___sub__(self, value)

    def __imul__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medmesh.MEDFLOAT___imul__(self, value)

    def __mul__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medmesh.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDFLOAT') -> "bool":
        return _medmesh.MEDFLOAT___le__(self, value)

    def __lt__(self, value: 'MEDFLOAT') -> "bool":
        return _medmesh.MEDFLOAT___lt__(self, value)

    def __gt__(self, value: 'MEDFLOAT') -> "bool":
        return _medmesh.MEDFLOAT___gt__(self, value)

    def __ge__(self, value: 'MEDFLOAT') -> "bool":
        return _medmesh.MEDFLOAT___ge__(self, value)

    def __eq__(self, value: 'MEDFLOAT') -> "bool":
        return _medmesh.MEDFLOAT___eq__(self, value)

    def __ne__(self, value: 'MEDFLOAT') -> "bool":
        return _medmesh.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDFLOAT
    __del__ = lambda self: None
MEDFLOAT_swigregister = _medmesh.MEDFLOAT_swigregister
MEDFLOAT_swigregister(MEDFLOAT)


MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT32, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT32, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medmesh.MEDFLOAT32___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medmesh.MEDFLOAT32___bool__(self)

    def __len__(self) -> "std::vector< float >::size_type":
        return _medmesh.MEDFLOAT32___len__(self)

    def __getslice__(self, i: 'std::vector< float >::difference_type', j: 'std::vector< float >::difference_type') -> "std::vector< float,std::allocator< float > > *":
        return _medmesh.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medmesh.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< float >::difference_type', j: 'std::vector< float >::difference_type') -> "void":
        return _medmesh.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medmesh.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< float >::value_type const &":
        return _medmesh.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medmesh.MEDFLOAT32___setitem__(self, *args)

    def pop(self) -> "std::vector< float >::value_type":
        return _medmesh.MEDFLOAT32_pop(self)

    def append(self, x: 'std::vector< float >::value_type const &') -> "void":
        return _medmesh.MEDFLOAT32_append(self, x)

    def empty(self) -> "bool":
        return _medmesh.MEDFLOAT32_empty(self)

    def size(self) -> "std::vector< float >::size_type":
        return _medmesh.MEDFLOAT32_size(self)

    def swap(self, v: 'MEDFLOAT32') -> "void":
        return _medmesh.MEDFLOAT32_swap(self, v)

    def begin(self) -> "std::vector< float >::iterator":
        return _medmesh.MEDFLOAT32_begin(self)

    def end(self) -> "std::vector< float >::iterator":
        return _medmesh.MEDFLOAT32_end(self)

    def rbegin(self) -> "std::vector< float >::reverse_iterator":
        return _medmesh.MEDFLOAT32_rbegin(self)

    def rend(self) -> "std::vector< float >::reverse_iterator":
        return _medmesh.MEDFLOAT32_rend(self)

    def clear(self) -> "void":
        return _medmesh.MEDFLOAT32_clear(self)

    def get_allocator(self) -> "std::vector< float >::allocator_type":
        return _medmesh.MEDFLOAT32_get_allocator(self)

    def pop_back(self) -> "void":
        return _medmesh.MEDFLOAT32_pop_back(self)

    def erase(self, *args) -> "std::vector< float >::iterator":
        return _medmesh.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        this = _medmesh.new_MEDFLOAT32(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< float >::value_type const &') -> "void":
        return _medmesh.MEDFLOAT32_push_back(self, x)

    def front(self) -> "std::vector< float >::value_type const &":
        return _medmesh.MEDFLOAT32_front(self)

    def back(self) -> "std::vector< float >::value_type const &":
        return _medmesh.MEDFLOAT32_back(self)

    def assign(self, n: 'std::vector< float >::size_type', x: 'std::vector< float >::value_type const &') -> "void":
        return _medmesh.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medmesh.MEDFLOAT32_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medmesh.MEDFLOAT32_insert(self, *args)

    def reserve(self, n: 'std::vector< float >::size_type') -> "void":
        return _medmesh.MEDFLOAT32_reserve(self, n)

    def capacity(self) -> "std::vector< float >::size_type":
        return _medmesh.MEDFLOAT32_capacity(self)

    def __iadd__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medmesh.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medmesh.MEDFLOAT32___add__(self, value)

    def __isub__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medmesh.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medmesh.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medmesh.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medmesh.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDFLOAT32') -> "bool":
        return _medmesh.MEDFLOAT32___le__(self, value)

    def __lt__(self, value: 'MEDFLOAT32') -> "bool":
        return _medmesh.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value: 'MEDFLOAT32') -> "bool":
        return _medmesh.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value: 'MEDFLOAT32') -> "bool":
        return _medmesh.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value: 'MEDFLOAT32') -> "bool":
        return _medmesh.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value: 'MEDFLOAT32') -> "bool":
        return _medmesh.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDFLOAT32
    __del__ = lambda self: None
MEDFLOAT32_swigregister = _medmesh.MEDFLOAT32_swigregister
MEDFLOAT32_swigregister(MEDFLOAT32)


MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDINT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDINT, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medmesh.MEDINT___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medmesh.MEDINT___bool__(self)

    def __len__(self) -> "std::vector< int >::size_type":
        return _medmesh.MEDINT___len__(self)

    def __getslice__(self, i: 'std::vector< int >::difference_type', j: 'std::vector< int >::difference_type') -> "std::vector< int,std::allocator< int > > *":
        return _medmesh.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medmesh.MEDINT___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< int >::difference_type', j: 'std::vector< int >::difference_type') -> "void":
        return _medmesh.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medmesh.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< int >::value_type const &":
        return _medmesh.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medmesh.MEDINT___setitem__(self, *args)

    def pop(self) -> "std::vector< int >::value_type":
        return _medmesh.MEDINT_pop(self)

    def append(self, x: 'std::vector< int >::value_type const &') -> "void":
        return _medmesh.MEDINT_append(self, x)

    def empty(self) -> "bool":
        return _medmesh.MEDINT_empty(self)

    def size(self) -> "std::vector< int >::size_type":
        return _medmesh.MEDINT_size(self)

    def swap(self, v: 'MEDINT') -> "void":
        return _medmesh.MEDINT_swap(self, v)

    def begin(self) -> "std::vector< int >::iterator":
        return _medmesh.MEDINT_begin(self)

    def end(self) -> "std::vector< int >::iterator":
        return _medmesh.MEDINT_end(self)

    def rbegin(self) -> "std::vector< int >::reverse_iterator":
        return _medmesh.MEDINT_rbegin(self)

    def rend(self) -> "std::vector< int >::reverse_iterator":
        return _medmesh.MEDINT_rend(self)

    def clear(self) -> "void":
        return _medmesh.MEDINT_clear(self)

    def get_allocator(self) -> "std::vector< int >::allocator_type":
        return _medmesh.MEDINT_get_allocator(self)

    def pop_back(self) -> "void":
        return _medmesh.MEDINT_pop_back(self)

    def erase(self, *args) -> "std::vector< int >::iterator":
        return _medmesh.MEDINT_erase(self, *args)

    def __init__(self, *args):
        this = _medmesh.new_MEDINT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< int >::value_type const &') -> "void":
        return _medmesh.MEDINT_push_back(self, x)

    def front(self) -> "std::vector< int >::value_type const &":
        return _medmesh.MEDINT_front(self)

    def back(self) -> "std::vector< int >::value_type const &":
        return _medmesh.MEDINT_back(self)

    def assign(self, n: 'std::vector< int >::size_type', x: 'std::vector< int >::value_type const &') -> "void":
        return _medmesh.MEDINT_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medmesh.MEDINT_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medmesh.MEDINT_insert(self, *args)

    def reserve(self, n: 'std::vector< int >::size_type') -> "void":
        return _medmesh.MEDINT_reserve(self, n)

    def capacity(self) -> "std::vector< int >::size_type":
        return _medmesh.MEDINT_capacity(self)

    def __iadd__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medmesh.MEDINT___iadd__(self, value)

    def __add__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medmesh.MEDINT___add__(self, value)

    def __isub__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medmesh.MEDINT___isub__(self, value)

    def __sub__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medmesh.MEDINT___sub__(self, value)

    def __imul__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medmesh.MEDINT___imul__(self, value)

    def __mul__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medmesh.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDINT') -> "bool":
        return _medmesh.MEDINT___le__(self, value)

    def __lt__(self, value: 'MEDINT') -> "bool":
        return _medmesh.MEDINT___lt__(self, value)

    def __gt__(self, value: 'MEDINT') -> "bool":
        return _medmesh.MEDINT___gt__(self, value)

    def __ge__(self, value: 'MEDINT') -> "bool":
        return _medmesh.MEDINT___ge__(self, value)

    def __eq__(self, value: 'MEDINT') -> "bool":
        return _medmesh.MEDINT___eq__(self, value)

    def __ne__(self, value: 'MEDINT') -> "bool":
        return _medmesh.MEDINT___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDINT
    __del__ = lambda self: None
MEDINT_swigregister = _medmesh.MEDINT_swigregister
MEDINT_swigregister(MEDINT)


MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDCHAR, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDCHAR, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medmesh_module *":
        return _medmesh.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medmesh.MEDCHAR___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medmesh.MEDCHAR___bool__(self)

    def __len__(self) -> "std::vector< char >::size_type":
        return _medmesh.MEDCHAR___len__(self)

    def __getslice__(self, i: 'std::vector< char >::difference_type', j: 'std::vector< char >::difference_type') -> "std::vector< char,std::allocator< char > > *":
        return _medmesh.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medmesh.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< char >::difference_type', j: 'std::vector< char >::difference_type') -> "void":
        return _medmesh.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medmesh.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< char >::value_type const &":
        return _medmesh.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medmesh.MEDCHAR___setitem__(self, *args)

    def pop(self) -> "std::vector< char >::value_type":
        return _medmesh.MEDCHAR_pop(self)

    def append(self, x: 'std::vector< char >::value_type const &') -> "void":
        return _medmesh.MEDCHAR_append(self, x)

    def empty(self) -> "bool":
        return _medmesh.MEDCHAR_empty(self)

    def size(self) -> "std::vector< char >::size_type":
        return _medmesh.MEDCHAR_size(self)

    def swap(self, v: 'MEDCHAR') -> "void":
        return _medmesh.MEDCHAR_swap(self, v)

    def begin(self) -> "std::vector< char >::iterator":
        return _medmesh.MEDCHAR_begin(self)

    def end(self) -> "std::vector< char >::iterator":
        return _medmesh.MEDCHAR_end(self)

    def rbegin(self) -> "std::vector< char >::reverse_iterator":
        return _medmesh.MEDCHAR_rbegin(self)

    def rend(self) -> "std::vector< char >::reverse_iterator":
        return _medmesh.MEDCHAR_rend(self)

    def clear(self) -> "void":
        return _medmesh.MEDCHAR_clear(self)

    def get_allocator(self) -> "std::vector< char >::allocator_type":
        return _medmesh.MEDCHAR_get_allocator(self)

    def pop_back(self) -> "void":
        return _medmesh.MEDCHAR_pop_back(self)

    def erase(self, *args) -> "std::vector< char >::iterator":
        return _medmesh.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        this = _medmesh.new_MEDCHAR(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< char >::value_type const &') -> "void":
        return _medmesh.MEDCHAR_push_back(self, x)

    def front(self) -> "std::vector< char >::value_type const &":
        return _medmesh.MEDCHAR_front(self)

    def back(self) -> "std::vector< char >::value_type const &":
        return _medmesh.MEDCHAR_back(self)

    def assign(self, n: 'std::vector< char >::size_type', x: 'std::vector< char >::value_type const &') -> "void":
        return _medmesh.MEDCHAR_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medmesh.MEDCHAR_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medmesh.MEDCHAR_insert(self, *args)

    def reserve(self, n: 'std::vector< char >::size_type') -> "void":
        return _medmesh.MEDCHAR_reserve(self, n)

    def capacity(self) -> "std::vector< char >::size_type":
        return _medmesh.MEDCHAR_capacity(self)

    def __iadd__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medmesh.MEDCHAR___iadd__(self, value)

    def __add__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medmesh.MEDCHAR___add__(self, value)

    def __isub__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medmesh.MEDCHAR___isub__(self, value)

    def __sub__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medmesh.MEDCHAR___sub__(self, value)

    def __imul__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medmesh.MEDCHAR___imul__(self, value)

    def __mul__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medmesh.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medmesh.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medmesh.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDCHAR') -> "bool":
        return _medmesh.MEDCHAR___le__(self, value)

    def __lt__(self, value: 'MEDCHAR') -> "bool":
        return _medmesh.MEDCHAR___lt__(self, value)

    def __gt__(self, value: 'MEDCHAR') -> "bool":
        return _medmesh.MEDCHAR___gt__(self, value)

    def __ge__(self, value: 'MEDCHAR') -> "bool":
        return _medmesh.MEDCHAR___ge__(self, value)

    def __eq__(self, value: 'MEDCHAR') -> "bool":
        return _medmesh.MEDCHAR___eq__(self, value)

    def __ne__(self, value: 'MEDCHAR') -> "bool":
        return _medmesh.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medmesh.delete_MEDCHAR
    __del__ = lambda self: None
MEDCHAR_swigregister = _medmesh.MEDCHAR_swigregister
MEDCHAR_swigregister(MEDCHAR)


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDmeshCr(fid: 'med_idt const', meshname: 'char const *const', spacedim: 'med_int const', meshdim: 'med_int const', meshtype: 'med_mesh_type const', description: 'char const *const', dtunit: 'char const *const', sortingtype: 'med_sorting_type const', axistype: 'med_axis_type const', axisname: 'char const *const', axisunit: 'char const *const') -> "char const *const, char const *const, char const *const, char const *const, char const *const":
    """
    MEDmeshCr(fid, meshname, spacedim, meshdim, meshtype, description, dtunit, sortingtype, axistype, axisname, axisunit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    spacedim: med_int const
    meshdim: med_int const
    meshtype: enum med_mesh_type const
    description: char const *const
    dtunit: char const *const
    sortingtype: enum med_sorting_type const
    axistype: enum med_axis_type const
    axisname: char const *const
    axisunit: char const *const


    Essai d Ajout a La Documentation Automatique
    """
    return _medmesh.MEDmeshCr(fid, meshname, spacedim, meshdim, meshtype, description, dtunit, sortingtype, axistype, axisname, axisunit)

def MEDmeshInfoByName(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const, med_int *const, med_int *const, med_mesh_type *, char *const, char *const, med_sorting_type *, med_int *const, med_axis_type *, char *const, char *const":
    """
    MEDmeshInfoByName(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshInfoByName(fid, meshname)

def MEDmeshInfo(fid: 'med_idt const', meshit: 'int const') -> "char *const, med_int *const, med_int *const, med_mesh_type *, char *const, char *const, med_sorting_type *, med_int *const, med_axis_type *, char *const, char *const":
    """
    MEDmeshInfo(fid, meshit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshit: int const

    """
    return _medmesh.MEDmeshInfo(fid, meshit)

def MEDnMesh(fid: 'med_idt const') -> "med_int":
    """
    MEDnMesh(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medmesh.MEDnMesh(fid)

def MEDmeshnAxis(fid: 'med_idt const', meshit: 'int const') -> "med_int":
    """
    MEDmeshnAxis(fid, meshit) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshit: int const

    """
    return _medmesh.MEDmeshnAxis(fid, meshit)

def MEDmeshnAxisByName(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const":
    """
    MEDmeshnAxisByName(fid, meshname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshnAxisByName(fid, meshname)

def MEDmeshGridTypeWr(fid: 'med_idt const', meshname: 'char const *const', gridtype: 'med_grid_type const') -> "char const *const":
    """
    MEDmeshGridTypeWr(fid, meshname, gridtype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    gridtype: enum med_grid_type const

    """
    return _medmesh.MEDmeshGridTypeWr(fid, meshname, gridtype)

def MEDmeshGridTypeRd(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const, med_grid_type *":
    """
    MEDmeshGridTypeRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshGridTypeRd(fid, meshname)

def MEDmeshGridIndexCoordinateWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', axis: 'med_int const', indexsize: 'med_int const', gridindex: 'med_float const *const') -> "char const *const, med_float const *const":
    """
    MEDmeshGridIndexCoordinateWr(fid, meshname, numdt, numit, dt, axis, indexsize, gridindex) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    axis: med_int const
    indexsize: med_int const
    gridindex: med_float const *const

    """
    return _medmesh.MEDmeshGridIndexCoordinateWr(fid, meshname, numdt, numit, dt, axis, indexsize, gridindex)

def MEDmeshGridIndexCoordinateRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', axis: 'med_int const', gridindex: 'med_float *const') -> "char const *const, med_float *const":
    """
    MEDmeshGridIndexCoordinateRd(fid, meshname, numdt, numit, axis, gridindex) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    axis: med_int const
    gridindex: med_float *const

    """
    return _medmesh.MEDmeshGridIndexCoordinateRd(fid, meshname, numdt, numit, axis, gridindex)

def MEDmeshGridStructWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', gridstruct: 'med_int const *const') -> "char const *const, med_int const *const":
    """
    MEDmeshGridStructWr(fid, meshname, numdt, numit, dt, gridstruct) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    gridstruct: med_int const *const

    """
    return _medmesh.MEDmeshGridStructWr(fid, meshname, numdt, numit, dt, gridstruct)

def MEDmeshGridStructRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', gridstruct: 'med_int *const') -> "char const *const, med_int *const":
    """
    MEDmeshGridStructRd(fid, meshname, numdt, numit, gridstruct) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    gridstruct: med_int *const

    """
    return _medmesh.MEDmeshGridStructRd(fid, meshname, numdt, numit, gridstruct)

def MEDmeshUniversalNameWr(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const":
    """
    MEDmeshUniversalNameWr(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshUniversalNameWr(fid, meshname)

def MEDmeshUniversalNameRd(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const, char *const":
    """
    MEDmeshUniversalNameRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshUniversalNameRd(fid, meshname)

def MEDmeshComputationStepCr(fid: 'med_idt const', meshname: 'char const *const', numdt1: 'med_int const', numit1: 'med_int const', numdt2: 'med_int const', numit2: 'med_int const', dt2: 'med_float const') -> "char const *const":
    """
    MEDmeshComputationStepCr(fid, meshname, numdt1, numit1, numdt2, numit2, dt2) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt1: med_int const
    numit1: med_int const
    numdt2: med_int const
    numit2: med_int const
    dt2: med_float const

    """
    return _medmesh.MEDmeshComputationStepCr(fid, meshname, numdt1, numit1, numdt2, numit2, dt2)

def MEDmeshAttributeRd(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const, med_int *const, med_int *const, med_int *const":
    """
    MEDmeshAttributeRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshAttributeRd(fid, meshname)

def MEDmeshAttributeWr(fid: 'med_idt const', meshname: 'char const *const', isolatednodes: 'med_int const', verticesnodes: 'med_int const', cellmaxnodes: 'med_int const') -> "char const *const":
    """
    MEDmeshAttributeWr(fid, meshname, isolatednodes, verticesnodes, cellmaxnodes) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    isolatednodes: med_int const
    verticesnodes: med_int const
    cellmaxnodes: med_int const

    """
    return _medmesh.MEDmeshAttributeWr(fid, meshname, isolatednodes, verticesnodes, cellmaxnodes)

def MEDmeshComputationStepDtRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', umit: 'med_int const') -> "char const *const, med_float *const":
    """
    MEDmeshComputationStepDtRd(fid, meshname, numdt, umit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    umit: med_int const

    """
    return _medmesh.MEDmeshComputationStepDtRd(fid, meshname, numdt, umit)

def MEDmeshComputationStepInfo(fid: 'med_idt const', meshname: 'char const *const', csit: 'int const') -> "char const *const, med_int *const, med_int *const, med_float *const":
    """
    MEDmeshComputationStepInfo(fid, meshname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    csit: int const

    """
    return _medmesh.MEDmeshComputationStepInfo(fid, meshname, csit)

def MEDmeshSortingTypeRd(fid: 'med_idt const', meshname: 'char const *const') -> "char const *const, med_sorting_type *":
    """
    MEDmeshSortingTypeRd(fid, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const

    """
    return _medmesh.MEDmeshSortingTypeRd(fid, meshname)

def MEDmeshNodeCoordinateAdvancedWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', filter: 'med_filter', value: 'med_float const *const') -> "char const *const, med_float const *const":
    """
    MEDmeshNodeCoordinateAdvancedWr(fid, meshname, numdt, numit, dt, filter, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    filter: med_filter const *const
    value: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateAdvancedWr(fid, meshname, numdt, numit, dt, filter, value)

def MEDmeshNodeCoordinateWithProfileWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', storagemode: 'med_storage_mode const', profilename: 'char const *const', switchmode: 'med_switch_mode const', dimselect: 'med_int const', nentity: 'med_int const', coordinates: 'med_float const *const') -> "char const *const, char const *const, med_float const *const":
    """
    MEDmeshNodeCoordinateWithProfileWr(fid, meshname, numdt, numit, dt, storagemode, profilename, switchmode, dimselect, nentity, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    nentity: med_int const
    coordinates: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateWithProfileWr(fid, meshname, numdt, numit, dt, storagemode, profilename, switchmode, dimselect, nentity, coordinates)

def MEDmeshNodeCoordinateWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', switchmode: 'med_switch_mode const', nentity: 'med_int const', coordinates: 'med_float const *const') -> "char const *const, med_float const *const":
    """
    MEDmeshNodeCoordinateWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    coordinates: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinates)

def MEDmeshNodeCoordinateTrsfWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', coordinatetrsf: 'med_float const *const') -> "char const *const, med_float const *const":
    """
    MEDmeshNodeCoordinateTrsfWr(fid, meshname, numdt, numit, dt, coordinatetrsf) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    coordinatetrsf: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateTrsfWr(fid, meshname, numdt, numit, dt, coordinatetrsf)

def MEDmeshNodeCoordinateTrsfRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', coordinatetrsf: 'med_float const *const') -> "char const *const, med_float const *const":
    """
    MEDmeshNodeCoordinateTrsfRd(fid, meshname, numdt, numit, coordinatetrsf) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    coordinatetrsf: med_float const *const

    """
    return _medmesh.MEDmeshNodeCoordinateTrsfRd(fid, meshname, numdt, numit, coordinatetrsf)

def MEDmeshElementConnectivityWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', switchmode: 'med_switch_mode const', nentity: 'med_int const', connectivity: 'med_int const *const') -> "char const *const, med_int const *const":
    """
    MEDmeshElementConnectivityWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshElementConnectivityWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity)

def MEDmeshElementConnectivityAdvancedWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', filter: 'med_filter', connectivity: 'med_int const *const') -> "char const *const, med_int const *const":
    """
    MEDmeshElementConnectivityAdvancedWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, filter, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    filter: med_filter const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshElementConnectivityAdvancedWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, filter, connectivity)

def MEDmeshElementConnectivityWithProfileWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', storagemode: 'med_storage_mode const', profilename: 'char const *const', switchmode: 'med_switch_mode const', dimselect: 'med_int const', nentity: 'med_int const', connectivity: 'med_int const *const') -> "char const *const, char const *const, med_int const *const":
    """
    MEDmeshElementConnectivityWithProfileWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    nentity: med_int const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshElementConnectivityWithProfileWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity)

def MEDmeshNodeCoordinateAdvancedRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', filter: 'med_filter', value: 'med_float *const') -> "char const *const, med_float *const":
    """
    MEDmeshNodeCoordinateAdvancedRd(fid, meshname, numdt, numit, filter, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    filter: med_filter const *const
    value: med_float *const

    """
    return _medmesh.MEDmeshNodeCoordinateAdvancedRd(fid, meshname, numdt, numit, filter, value)

def MEDmeshNodeCoordinateWithProfileRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', storagemode: 'med_storage_mode const', profilename: 'char const *const', switchmode: 'med_switch_mode const', dimselect: 'med_int const', coordinates: 'med_float *const') -> "char const *const, char const *const, med_float *const":
    """
    MEDmeshNodeCoordinateWithProfileRd(fid, meshname, numdt, numit, storagemode, profilename, switchmode, dimselect, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    coordinates: med_float *const

    """
    return _medmesh.MEDmeshNodeCoordinateWithProfileRd(fid, meshname, numdt, numit, storagemode, profilename, switchmode, dimselect, coordinates)

def MEDmeshNodeCoordinateRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', switchmode: 'med_switch_mode const', coordinates: 'med_float *const') -> "char const *const, med_float *const":
    """
    MEDmeshNodeCoordinateRd(fid, meshname, numdt, numit, switchmode, coordinates) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    switchmode: enum med_switch_mode const
    coordinates: med_float *const

    """
    return _medmesh.MEDmeshNodeCoordinateRd(fid, meshname, numdt, numit, switchmode, coordinates)

def MEDmeshElementConnectivityRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', switchmode: 'med_switch_mode const', connectivity: 'med_int *const') -> "char const *const, med_int *const":
    """
    MEDmeshElementConnectivityRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshElementConnectivityRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity)

def MEDmeshElementConnectivityAdvancedRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', filter: 'med_filter', connectivity: 'med_int *const') -> "char const *const, med_int *const":
    """
    MEDmeshElementConnectivityAdvancedRd(fid, meshname, numdt, numit, entitype, geotype, cmode, filter, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    filter: med_filter const *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshElementConnectivityAdvancedRd(fid, meshname, numdt, numit, entitype, geotype, cmode, filter, connectivity)

def MEDmeshElementConnectivityWithProfileRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', storagemode: 'med_storage_mode const', profilename: 'char const *const', switchmode: 'med_switch_mode const', dimselect: 'med_int const', nentity: 'med_int const', connectivity: 'med_int *const') -> "char const *const, char const *const, med_int *const":
    """
    MEDmeshElementConnectivityWithProfileRd(fid, meshname, numdt, numit, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    dimselect: med_int const
    nentity: med_int const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshElementConnectivityWithProfileRd(fid, meshname, numdt, numit, entitype, geotype, cmode, storagemode, profilename, switchmode, dimselect, nentity, connectivity)

def MEDmeshnEntity(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', datatype: 'med_data_type const', cmode: 'med_connectivity_mode const') -> "char const *const, med_bool *, med_bool *":
    """
    MEDmeshnEntity(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    datatype: enum med_data_type const
    cmode: enum med_connectivity_mode const

    """
    return _medmesh.MEDmeshnEntity(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode)

def MEDmeshnEntityWithProfile(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', datatype: 'med_data_type const', cmode: 'med_connectivity_mode const', storagemode: 'med_storage_mode const') -> "char const *const, char *const, med_int *const, med_bool *, med_bool *":
    """
    MEDmeshnEntityWithProfile(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode, storagemode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    datatype: enum med_data_type const
    cmode: enum med_connectivity_mode const
    storagemode: enum med_storage_mode const

    """
    return _medmesh.MEDmeshnEntityWithProfile(fid, meshname, numdt, numit, entitype, geotype, datatype, cmode, storagemode)

def MEDmeshEntityInfo(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotypeit: 'int const', geotype: 'med_geometry_type *const') -> "char const *const, char *const":
    """
    MEDmeshEntityInfo(fid, meshname, numdt, numit, entitype, geotypeit, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotypeit: int const
    geotype: med_geometry_type *const

    """
    return _medmesh.MEDmeshEntityInfo(fid, meshname, numdt, numit, entitype, geotypeit, geotype)

def MEDmeshEntityNameWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', nentity: 'med_int const', name: 'char const *const') -> "char const *const, char const *const":
    """
    MEDmeshEntityNameWr(fid, meshname, numdt, numit, entitype, geotype, nentity, name) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    name: char const *const

    """
    return _medmesh.MEDmeshEntityNameWr(fid, meshname, numdt, numit, entitype, geotype, nentity, name)

def MEDmeshEntityNameRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', name: 'char *const') -> "char const *const, char *const":
    """
    MEDmeshEntityNameRd(fid, meshname, numdt, numit, entitype, geotype, name) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    name: char *const

    """
    return _medmesh.MEDmeshEntityNameRd(fid, meshname, numdt, numit, entitype, geotype, name)

def MEDmeshEntityNumberWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', nentity: 'med_int const', number: 'med_int const *const') -> "char const *const, med_int const *const":
    """
    MEDmeshEntityNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    number: med_int const *const

    """
    return _medmesh.MEDmeshEntityNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number)

def MEDmeshEntityNumberRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', number: 'med_int *const') -> "char const *const, med_int *const":
    """
    MEDmeshEntityNumberRd(fid, meshname, numdt, numit, entitype, geotype, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    number: med_int *const

    """
    return _medmesh.MEDmeshEntityNumberRd(fid, meshname, numdt, numit, entitype, geotype, number)

def MEDmeshEntityFamilyNumberWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', nentity: 'med_int const', number: 'med_int const *const') -> "char const *const, med_int const *const":
    """
    MEDmeshEntityFamilyNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    number: med_int const *const

    """
    return _medmesh.MEDmeshEntityFamilyNumberWr(fid, meshname, numdt, numit, entitype, geotype, nentity, number)

def MEDmeshEntityFamilyNumberRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', number: 'med_int *const') -> "char const *const, med_int *const":
    """
    MEDmeshEntityFamilyNumberRd(fid, meshname, numdt, numit, entitype, geotype, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    number: med_int *const

    """
    return _medmesh.MEDmeshEntityFamilyNumberRd(fid, meshname, numdt, numit, entitype, geotype, number)

def MEDmeshEntityAttributeAdvancedRd(fid: 'med_idt const', meshname: 'char const *const', datatype: 'med_data_type const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', filter: 'med_filter', attval: 'void *const') -> "char const *const":
    """
    MEDmeshEntityAttributeAdvancedRd(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    datatype: enum med_data_type const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    filter: med_filter const *const
    attval: void *const

    """
    return _medmesh.MEDmeshEntityAttributeAdvancedRd(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval)

def MEDmeshEntityAttributeAdvancedWr(fid: 'med_idt const', meshname: 'char const *const', datatype: 'med_data_type const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', filter: 'med_filter', attval: 'void const *const') -> "char const *const":
    """
    MEDmeshEntityAttributeAdvancedWr(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    datatype: enum med_data_type const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    filter: med_filter const *const
    attval: void const *const

    """
    return _medmesh.MEDmeshEntityAttributeAdvancedWr(fid, meshname, datatype, numdt, numit, entitype, geotype, filter, attval)

def MEDmeshPolygonWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', cmode: 'med_connectivity_mode const', indexsize: 'med_int const', polyindex: 'med_int const *const', connectivity: 'med_int const *const') -> "char const *const, med_int const *const, med_int const *const":
    """
    MEDmeshPolygonWr(fid, meshname, numdt, numit, dt, entitype, cmode, indexsize, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    indexsize: med_int const
    polyindex: med_int const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshPolygonWr(fid, meshname, numdt, numit, dt, entitype, cmode, indexsize, polyindex, connectivity)

def MEDmeshPolygon2Wr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', polytype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', indexsize: 'med_int const', polyindex: 'med_int const *const', connectivity: 'med_int const *const') -> "char const *const, med_int const *const, med_int const *const":
    """
    MEDmeshPolygon2Wr(fid, meshname, numdt, numit, dt, entitype, polytype, cmode, indexsize, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    polytype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    indexsize: med_int const
    polyindex: med_int const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshPolygon2Wr(fid, meshname, numdt, numit, dt, entitype, polytype, cmode, indexsize, polyindex, connectivity)

def MEDmeshPolygonRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', cmode: 'med_connectivity_mode const', polyindex: 'med_int *const', connectivity: 'med_int *const') -> "char const *const, med_int *const, med_int *const":
    """
    MEDmeshPolygonRd(fid, meshname, numdt, numit, entitype, cmode, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    polyindex: med_int *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshPolygonRd(fid, meshname, numdt, numit, entitype, cmode, polyindex, connectivity)

def MEDmeshPolygon2Rd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', polytype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', polyindex: 'med_int *const', connectivity: 'med_int *const') -> "char const *const, med_int *const, med_int *const":
    """
    MEDmeshPolygon2Rd(fid, meshname, numdt, numit, entitype, polytype, cmode, polyindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    polytype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    polyindex: med_int *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshPolygon2Rd(fid, meshname, numdt, numit, entitype, polytype, cmode, polyindex, connectivity)

def MEDmeshPolyhedronRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', cmode: 'med_connectivity_mode const', faceindex: 'med_int *const', nodeindex: 'med_int *const', connectivity: 'med_int *const') -> "char const *const, med_int *const, med_int *const, med_int *const":
    """
    MEDmeshPolyhedronRd(fid, meshname, numdt, numit, entitype, cmode, faceindex, nodeindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    faceindex: med_int *const
    nodeindex: med_int *const
    connectivity: med_int *const

    """
    return _medmesh.MEDmeshPolyhedronRd(fid, meshname, numdt, numit, entitype, cmode, faceindex, nodeindex, connectivity)

def MEDmeshPolyhedronWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', cmode: 'med_connectivity_mode const', faceindexsize: 'med_int const', faceindex: 'med_int const *const', nodeindexsize: 'med_int const', nodeindex: 'med_int const *const', connectivity: 'med_int const *const') -> "char const *const, med_int const *const, med_int const *const, med_int const *const":
    """
    MEDmeshPolyhedronWr(fid, meshname, numdt, numit, dt, entitype, cmode, faceindexsize, faceindex, nodeindexsize, nodeindex, connectivity) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    cmode: enum med_connectivity_mode const
    faceindexsize: med_int const
    faceindex: med_int const *const
    nodeindexsize: med_int const
    nodeindex: med_int const *const
    connectivity: med_int const *const

    """
    return _medmesh.MEDmeshPolyhedronWr(fid, meshname, numdt, numit, dt, entitype, cmode, faceindexsize, faceindex, nodeindexsize, nodeindex, connectivity)

def MEDmeshGeotypeName(fid: 'med_idt const', geotype: 'med_geometry_type const') -> "char *const":
    """
    MEDmeshGeotypeName(fid, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    geotype: med_geometry_type const

    """
    return _medmesh.MEDmeshGeotypeName(fid, geotype)

def MEDmeshGeotypeParameter(fid: 'med_idt const', geotype: 'med_geometry_type const') -> "med_int *const, med_int *const":
    """
    MEDmeshGeotypeParameter(fid, geotype) -> med_err

    Parameters
    ----------
    fid: med_idt const
    geotype: med_geometry_type const

    """
    return _medmesh.MEDmeshGeotypeParameter(fid, geotype)

def MEDmeshGlobalNumberWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitytype: 'med_entity_type const', geotype: 'med_geometry_type const', nentity: 'med_int const', number: 'med_int const *const') -> "char const *const, med_int const *const":
    """
    MEDmeshGlobalNumberWr(fid, meshname, numdt, numit, entitytype, geotype, nentity, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitytype: enum med_entity_type const
    geotype: med_geometry_type const
    nentity: med_int const
    number: med_int const *const

    """
    return _medmesh.MEDmeshGlobalNumberWr(fid, meshname, numdt, numit, entitytype, geotype, nentity, number)

def MEDmeshGlobalNumberRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitytype: 'med_entity_type const', geotype: 'med_geometry_type const', number: 'med_int *const') -> "char const *const, med_int *const":
    """
    MEDmeshGlobalNumberRd(fid, meshname, numdt, numit, entitytype, geotype, number) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitytype: enum med_entity_type const
    geotype: med_geometry_type const
    number: med_int *const

    """
    return _medmesh.MEDmeshGlobalNumberRd(fid, meshname, numdt, numit, entitytype, geotype, number)

def MEDmeshNodeWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', switchmode: 'med_switch_mode const', nentity: 'med_int const', coordinate: 'med_float const *const', withnodename: 'med_bool const', nodename: 'char const *const', withnodenumber: 'med_bool const', nodenumber: 'med_int const *const', withfamnumber: 'med_bool const', famnumber: 'med_int const *const') -> "char const *const, med_float const *const, char const *const, med_int const *const, med_int const *const":
    """
    MEDmeshNodeWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinate, withnodename, nodename, withnodenumber, nodenumber, withfamnumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    coordinate: med_float const *const
    withnodename: enum med_bool const
    nodename: char const *const
    withnodenumber: enum med_bool const
    nodenumber: med_int const *const
    withfamnumber: enum med_bool const
    famnumber: med_int const *const

    """
    return _medmesh.MEDmeshNodeWr(fid, meshname, numdt, numit, dt, switchmode, nentity, coordinate, withnodename, nodename, withnodenumber, nodenumber, withfamnumber, famnumber)

def MEDmeshNodeRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', switchmode: 'med_switch_mode const', coordinate: 'med_float *const', nodename: 'char *const', nodenumber: 'med_int *const', famnumber: 'med_int *const') -> "char const *const, med_float *const, med_bool *, char *const, med_bool *, med_int *const, med_bool *, med_int *const":
    """
    MEDmeshNodeRd(fid, meshname, numdt, numit, switchmode, coordinate, nodename, nodenumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    switchmode: enum med_switch_mode const
    coordinate: med_float *const
    nodename: char *const
    nodenumber: med_int *const
    famnumber: med_int *const

    """
    return _medmesh.MEDmeshNodeRd(fid, meshname, numdt, numit, switchmode, coordinate, nodename, nodenumber, famnumber)

def MEDmeshElementWr(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', switchmode: 'med_switch_mode const', nentity: 'med_int const', connectivity: 'med_int const *const', withelementname: 'med_bool const', elementname: 'char const *const', withelementnumber: 'med_bool const', elementnumber: 'med_int const *const', withfamnumber: 'med_bool const', famnumber: 'med_int const *const') -> "char const *const, med_int const *const, char const *const, med_int const *const, med_int const *const":
    """
    MEDmeshElementWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity, withelementname, elementname, withelementnumber, elementnumber, withfamnumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    nentity: med_int const
    connectivity: med_int const *const
    withelementname: enum med_bool const
    elementname: char const *const
    withelementnumber: enum med_bool const
    elementnumber: med_int const *const
    withfamnumber: enum med_bool const
    famnumber: med_int const *const

    """
    return _medmesh.MEDmeshElementWr(fid, meshname, numdt, numit, dt, entitype, geotype, cmode, switchmode, nentity, connectivity, withelementname, elementname, withelementnumber, elementnumber, withfamnumber, famnumber)

def MEDmeshElementRd(fid: 'med_idt const', meshname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', cmode: 'med_connectivity_mode const', switchmode: 'med_switch_mode const', connectivity: 'med_int *const', elementname: 'char *const', elementnumber: 'med_int *const', famnumber: 'med_int *const') -> "char const *const, med_int *const, med_bool *, char *const, med_bool *, med_int *const, med_bool *, med_int *const":
    """
    MEDmeshElementRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity, elementname, elementnumber, famnumber) -> med_err

    Parameters
    ----------
    fid: med_idt const
    meshname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    cmode: enum med_connectivity_mode const
    switchmode: enum med_switch_mode const
    connectivity: med_int *const
    elementname: char *const
    elementnumber: med_int *const
    famnumber: med_int *const

    """
    return _medmesh.MEDmeshElementRd(fid, meshname, numdt, numit, entitype, geotype, cmode, switchmode, connectivity, elementname, elementnumber, famnumber)
# This file is compatible with both classic and new-style classes.





#                                               -*- Python -*-
#
#  __init__.py
#

"""
    MED --- _____ 
    ===================================================

    Documentation is available online at http://www.

    Contents
    --------
      Module MED imports all the functions from the MED modules.

    Available subpackages
    ---------------------

      medenum
      medequivalence
      medfamily
      medfield
      medfile
      medfilter
      medinterp
      medlibrary
      medlink
      medlocalization
      medmesh
      medparameter
      medprofile

    Utility tools
    -------------

    Environment variables
    ---------------------
    
"""
import os
import sys
import platform
import warnings
if platform.system() == "Windows":
    # the following line will be modified by the windows installer
    MED_PYTHON_PATH = ""
    if MED_PYTHON_PATH != "":
        # set Path to MED module
        os.environ['PATH'] = MED_PYTHON_PATH + ';' + os.environ['PATH']


# check if interactive mode
if not hasattr(sys, 'ps1'):
    try:
        # ipython does not define ps1
        __IPYTHON__
    except:
        # Reset the default Crtl-C behavior
        import signal
        try:
            signal.signal(signal.SIGINT, signal.SIG_DFL)
        except ValueError:
            pass

from .medenum import *
from .medequivalence import *
from .medfamily import *
from .medfield import *
from .medfile import *
from .medfilter import *
from .medinterp import *
from .medlibrary import *
from .medlink import *
from .medlocalization import *
from .medmesh import *
from .medparameter import *
from .medprofile import *


# define the version
#__version__ = PlatformInfo.GetVersion()
